==> django-secretary_0.2.0.orig.tar.gz: django-secretary-0.2.0/django_secretary/tests/test_settings.py <==
from unittest.mock import sentinel

from django.core.exceptions import ValidationError
from django.test import SimpleTestCase

from django_secretary.settings import MergeDictSetting, SignersSetting


class MergeDictSettingTest(SimpleTestCase):
    def test_update(self):
        setting = MergeDictSetting(default={'default': sentinel.default, 'override': sentinel.original})
        result = dict(default=sentinel.default, override=sentinel.override, unknown=sentinel.unknown)
        self.assertEqual(setting.transform({'override': sentinel.override, 'unknown': sentinel.unknown}), result)


class SignersSettingTest(SimpleTestCase):
    def test_transform(self):
        data = (
            # value, transformed
            ({}, {'ENVIRONMENT': None, 'OUTPUT': '{basename}_signed'}),
            ({'ENVIRONMENT': sentinel.env}, {'ENVIRONMENT': sentinel.env, 'OUTPUT': '{basename}_signed'}),
            ({'OUTPUT': sentinel.output}, {'ENVIRONMENT': None, 'OUTPUT': sentinel.output}),
        )
        setting = SignersSetting()
        for value, transformed in data:
            with self.subTest(value=value):
                self.assertEqual(setting.transform({'foo': value}), {'foo': transformed})

    def test_validate_valid(self):
        data = (
            {},
            {'foo': {'COMMAND': ['sign']}},
        )
        setting = SignersSetting()
        for value in data:
            with self.subTest(value=value):
                setting.validate(value)

    def test_validate_invalid(self):
        data = (
            # value, error
            ({}, "Every signer needs a COMMAND key."),
            ({'COMMAND': 'invalid'}, "COMMAND has to be a sequence of strings."),
            ({'COMMAND': [True]}, "COMMAND has to be a sequence of strings."),
            ({'COMMAND': [], 'ENVIRONMENT': 'invalid'}, "ENVIRONMENT has to be a mapping."),
            ({'COMMAND': [], 'OUTPUT': True}, "OUTPUT has to be a string."),
        )
        setting = SignersSetting()
        for value, error in data:
            with self.subTest(value=value):
                self.assertRaisesRegex(ValidationError, error, setting.validate, {'foo': value})

==> django-secretary_0.5.2.orig.tar.gz: django-secretary-0.5.2/django_secretary/tests/test_settings.py <==
from typing import Any, Dict, Iterable, Tuple
from unittest.mock import sentinel

from django.core.exceptions import ValidationError
from django.test import SimpleTestCase

from django_secretary.settings import MergeDictSetting, SignersSetting


class MergeDictSettingTest(SimpleTestCase):
    def test_update(self):
        setting = MergeDictSetting(default={'default': sentinel.default, 'override': sentinel.original})
        result = dict(default=sentinel.default, override=sentinel.override, unknown=sentinel.unknown)
        self.assertEqual(setting.transform({'override': sentinel.override, 'unknown': sentinel.unknown}), result)


class SignersSettingTest(SimpleTestCase):
    def test_transform(self):
        data: Iterable[Tuple[Dict[str, Any], Dict[str, Any]]] = (
            # value, transformed
            ({}, {'ENVIRONMENT': None, 'OUTPUT': 'input_signed.pdf'}),
            ({'ENVIRONMENT': sentinel.env}, {'ENVIRONMENT': sentinel.env, 'OUTPUT': 'input_signed.pdf'}),
            ({'OUTPUT': sentinel.output}, {'ENVIRONMENT': None, 'OUTPUT': sentinel.output}),
        )
        setting = SignersSetting()
        for value, transformed in data:
            with self.subTest(value=value):
                self.assertEqual(setting.transform({'foo': value}), {'foo': transformed})

    def test_validate_valid(self):
        data: Iterable[Dict[str, Any]] = (
            {},
            {'foo': {'COMMAND': ['sign']}},
        )
        setting = SignersSetting()
        for value in data:
            with self.subTest(value=value):
                setting.validate(value)

    def test_validate_invalid(self):
        data: Iterable[Tuple[Dict[str, Any], str]] = (
            # value, error
            ({}, "Every signer needs a COMMAND key."),
            ({'COMMAND': 'invalid'}, "COMMAND has to be a sequence of strings."),
            ({'COMMAND': [True]}, "COMMAND has to be a sequence of strings."),
            ({'COMMAND': [], 'ENVIRONMENT': 'invalid'}, "ENVIRONMENT has to be a mapping."),
            ({'COMMAND': [], 'OUTPUT': True}, "OUTPUT has to be a string."),
        )
        setting = SignersSetting()
        for value, error in data:
            with self.subTest(value=value):
                self.assertRaisesRegex(ValidationError, error, setting.validate, {'foo': value})
